@@ -1,6 +1,6 @@
 import warnings
 from datetime import date
-from typing import Any, Iterable, Optional, Sequence, TYPE_CHECKING, Union
+from typing import Any, Optional, Sequence, TYPE_CHECKING, Union
 
 if TYPE_CHECKING:
     # https://github.com/microsoft/pyright/issues/1358
@@ -239,7 +239,7 @@ def standardized_raw(
 def point_in_time(
     company_identifiers: CompanyIdentifiers = [],
     all_footnotes: bool = False,
-    metrics: Iterable[str] = [],
+    metrics: Sequence[str] = [],
     all_history: bool = False,
     entire_universe: bool = False,
     start_year: int = None,
@@ -312,7 +312,7 @@ def point_in_time(
 
     """
 
-    data = normalized_raw(
+    data = standardized_raw(
         company_identifiers=company_identifiers,
         all_face=all_face,
         all_footnotes=all_footnotes,
@@ -336,7 +336,7 @@ def point_in_time(
         return pd.DataFrame()
 
     data = pd.DataFrame(data)
-    data = data.drop(columns=["trace_facts"], errors="ignore")  # Those are annoying
+    data = data.drop(columns=["trace_facts"], errors="ignore")  # type: ignore
     sort_columns = ["ticker", "metric"]
 
     if "calendar_period" in data.columns:
@@ -350,10 +350,11 @@ def point_in_time(
         for date_column in ["date_reported", "period_end", "period_start"]:
             if date_column in data.columns:
                 data[date_column] = pd.to_datetime(data[date_column], errors="coerce")  # type: ignore
+
     return data.sort_values(sort_columns).reset_index(drop=True)
 
 
-def normalized_dataframe(
+def standardized_data(
     company_identifiers: CompanyIdentifiers = [],
     metrics: Sequence[str] = [],
     start_year: int = None,
@@ -411,7 +412,7 @@ def normalized_dataframe(
             "Cannot use combined because we can't build the time-series index"
         )
 
-    data = normalized_raw(
+    data = standardized_raw(
         company_identifiers=list(company_identifiers),
         metrics=metrics,
         start_year=start_year,
@@ -448,7 +449,7 @@ def normalized_dataframe(
         try:  # This is probably not necessary, we're doing it in the dataframe. akittredge January 2017.
             value = float(d["value"])
             if trace_hyperlinks:
-                value = f'=HYPERLINK("{d["trace_facts"][0]["trace_url"]}", {value})'
+                value = f'=HYPERLINK("{d["trace_url"]}", {value})'
             d["value"] = value
         except (ValueError, KeyError):
             pass
@@ -499,7 +500,7 @@ def _build_quarter_period(data_point, use_fiscal_period):
         return pd.Period()  # type: ignore
 
 
-def _build_annual_period(data_point, use_fiscal_period):
+def _build_annual_period(data_point: StandardizedPoint, use_fiscal_period):
     data_point.pop("fiscal_period" if use_fiscal_period else "calendar_period")
     return pd.Period(  # type: ignore
         year=data_point.pop("fiscal_year" if use_fiscal_period else "calendar_year"),
@@ -507,6 +508,6 @@ def _build_annual_period(data_point, use_fiscal_period):
     )
 
 
-normalized_data = normalized_dataframe  # used to call it normalized_data.
-standardized_data = normalized_dataframe  # Now it's called standardized data
+normalized_data = standardized_data  # used to call it normalized_data.
+normalized_dataframe = standardized_data
 normalized_raw = standardized_raw
\ No newline at end of file
